# This package contains macros that provide functionality relating to
# Software Collections. These macros are not used in default
# Fedora builds, and should not be blindly copied or enabled.
# Specifically, the "scl" macro must not be defined in official Fedora
# builds. For more information, see:
# http://docs.fedoraproject.org/en-US/Fedora_Contributor_Documentation
# /1/html/Software_Collections_Guide/index.html

%{?scl:%scl_package rubygem-%{gem_name}}
%{!?scl:%global pkg_name %{name}}

%global gem_name foreman_discovery

%define rubyabi 1.9.1
%global foreman_dir /usr/share/foreman
%global foreman_bundlerd_dir %{foreman_dir}/bundler.d

Summary:    MaaS Discovery Plugin for Foreman
Name:       %{?scl_prefix}rubygem-%{gem_name}
Version:    2.0.0.19
Release:    1%{?dist}
Group:      Applications/System
License:    GPLv3
URL:        http://github.com/theforeman/foreman_discovery
Source0:    %{gem_name}-%{version}.gem

Requires:   foreman >= 1.7.0
Requires:   %{?scl_prefix}rubygem(deface) < 1.0

%if 0%{?fedora} > 18
Requires: %{?scl_prefix}ruby(release)
%else
Requires: %{?scl_prefix}ruby(abi) >= %{rubyabi}
%endif
Requires: %{?scl_prefix}rubygems

%if 0%{?fedora} > 18
BuildRequires: %{?scl_prefix}ruby(release)
%else
BuildRequires: %{?scl_prefix}ruby(abi) >= %{rubyabi}
%endif
BuildRequires: %{?scl_prefix}rubygems-devel
BuildRequires: %{?scl_prefix}rubygems

BuildArch: noarch

Provides: %{?scl_prefix}rubygem(%{gem_name}) = %{version}
Provides: foreman-plugin-discovery

%description
MaaS Discovery Plugin engine for Foreman.

%package doc
BuildArch:  noarch
Requires:   %{?scl_prefix}%{pkg_name} = %{version}-%{release}
Summary:    Documentation for rubygem-%{gem_name}

%description doc
This package contains documentation for rubygem-%{gem_name}.

%prep
%setup -n %{gem_name}-%{version} -T -c
mkdir -p .%{gem_dir}
%{?scl:scl enable %{scl} "}
gem install --local --install-dir .%{gem_dir} \
            --force %{SOURCE0} --no-rdoc --no-ri
%{?scl:"}

%build

%install
mkdir -p %{buildroot}%{gem_dir}
cp -a .%{gem_dir}/* \
        %{buildroot}%{gem_dir}/

mkdir -p %{buildroot}%{foreman_bundlerd_dir}
cat <<GEMFILE > %{buildroot}%{foreman_bundlerd_dir}/%{gem_name}.rb
gem '%{gem_name}'
GEMFILE

%files
%dir %{gem_instdir}
%{gem_instdir}/app
%{gem_instdir}/lib
%{gem_instdir}/config
%{gem_instdir}/db
%exclude %{gem_instdir}/extra
%{gem_instdir}/locale
%exclude %{gem_cache}
%{gem_spec}
%{foreman_bundlerd_dir}/%{gem_name}.rb
%doc %{gem_instdir}/LICENSE

%exclude %{gem_instdir}/test
%exclude %{gem_dir}/cache/%{gem_name}-%{version}.gem

%files doc
%doc %{gem_instdir}/LICENSE
%doc %{gem_instdir}/README.md

%posttrans
# We need to run the db:migrate after the install transaction
/usr/sbin/foreman-rake db:migrate  >/dev/null 2>&1 || :
/usr/sbin/foreman-rake db:seed  >/dev/null 2>&1 || :
/usr/sbin/foreman-rake apipie:cache  >/dev/null 2>&1 || :
(/sbin/service foreman status && /sbin/service foreman restart) >/dev/null 2>&1
exit 0

%changelog
* Wed Jul 29 2015 Chris Peters <chrispeters.psu@gmail.com> 2.0.0.19-1
- bump version (chrispeters.psu@gmail.com)
- 1224158 - review auto provisioning and rules permissions
  (lzap+git@redhat.com)

* Tue Jul 21 2015 Chris Peters <chrispeters.psu@gmail.com> 2.0.0.18-1
- Version Bump (chrispeters.psu@gmail.com)
- Fixes #10195 - discovered node is no longer rebooted on error
  (lzap+git@redhat.com)

* Tue Jul 07 2015 Daniel Lobato <elobatocs@gmail.com> 2.0.0.17-1
* Tue Jul 07 2015 Daniel Lobato <elobatocs@gmail.com> 2.0.0.16-1
1202251
* Tue Jun 02 2015 Mike McCune <mmccune@redhat.com> 2.0.0.15-1
- Refs #9870 - adding error response code when auto-provision fails with no
  discovery rule (orabin@redhat.com)

* Tue May 19 2015 Mike McCune <mmccune@redhat.com> 2.0.0.14-1
- Fixes #10375 - entering edit form doesn't delete attributes
  (lzap+git@redhat.com)
- Fixes #9895 - user in Discovery Reader role should see discovery rules
  (orabin@redhat.com)

* Tue May 05 2015 Mike McCune <mmccune@redhat.com> 2.0.0.13-1
- Fixes #10365 - Removing all tokens when there are no managed hosts
  (orabin@redhat.com)
- Fix BZ#1215662 - ignore new interface attributes (mhulan@redhat.com)
- Pull in final french strings from zanata (bkearney@redhat.com)

* Wed Apr 29 2015 Mike McCune <mmccune@redhat.com> 2.0.0.12-1
- bump version (mmccune@redhat.com)

* Wed Apr 29 2015 Mike McCune <mmccune@redhat.com> 2.0.0.11-1
- Fixes #9912: Fix ambiguous column error by using table_name.
  (ericdhelms@gmail.com)

* Tue Apr 28 2015 Mike McCune <mmccune@redhat.com> 2.0.0.10-1
- Add in strings from zanata. All but french are done (bkearney@redhat.com)
- Fixes #9870 - Auto-provisioning a host, when no rule is defined, raises
  proper error (orabin@redhat.com)
- refs #9546 - moving host_converter to proper directory for rails
  (orabin@redhat.com)
- refs #9572 - api changes for cli (orabin@redhat.com)
- Fixes #9488 - migration to delete discovery_attribute_set from managed hosts
  (orabin@redhat.com)
- Refs #5701 - provided functional tests for edit html ids
  (lzap+git@redhat.com)
- Fixes #9546 - added converter STI helper API (lzap+git@redhat.com)
- Fixes #9552 - fixed routing for auto_provision from discovered host view
  (orabin@redhat.com)

* Tue Mar 24 2015 Jason Montleon <jmontleo@redhat.com> 2.0.0.9-1
- update version (jmontleo@redhat.com)
- 98+ percent on all strings (bkearney@redhat.com)

* Tue Mar 17 2015 Jason Montleon <jmontleo@redhat.com> 2.0.0.8-1
- update version (jmontleo@redhat.com)
- Add the latest strings, and new zanata file (bkearney@redhat.com)
- Add in the new zanata file (bkearney@redhat.com)

* Tue Mar 17 2015 Jason Montleon <jmontleo@redhat.com> 2.0.0.7-1
- update version (jmontleo@redhat.com)
- Fixes #9366 - host limit for discovery rule defaults to zero
  (orabin@redhat.com)

* Tue Mar 10 2015 Jason Montleon <jmontleo@redhat.com> 2.0.0.6-1
- update version (jmontleo@redhat.com)
- Fixes #9597 - migration to delete host token when provision failed
  (orabin@redhat.com)

* Wed Feb 18 2015 Jason Montleon <jmontleo@redhat.com> 2.0.0.5-1
- update version to 2.0.0.5 (jmontleo@redhat.com)

* Wed Feb 18 2015 Jason Montleon <jmontleo@redhat.com> 2.0.0.4-1
- fix provides version 

* Tue Feb 10 2015 Jason Montleon <jmontleo@redhat.com> 2.0.0.3-1
- Remove rc from rpm release 

* Tue Feb 10 2015 Jason Montleon <jmontleo@redhat.com> 2.0.0.2-1.rc2
- Bump to version 2.0.0 final (lzap+git@redhat.com)
- Fixes #9196 - Alter update RABL to not explode on discovery_attribute_set
  (gsutclif@redhat.com)

* Fri Jan 30 2015 Jason Montleon <jmontleo@redhat.com> 2.0.0.1-1.rc2
- update to 2.0.0.rc2 (jmontleo@redhat.com)
* Tue Jan 20 2015 Lukas Zapletal <lzap+rpm@redhat.com> - 2.0.0-0.1.rc1
- Dropped extra/ directory and TCL building dependencies
- Update to foreman_discovery 2.0.0.rc1

* Tue Nov 25 2014 Lukas Zapletal <lzap+rpm@redhat.com> - 1.4.1-1
- Update to foreman_discovery 1.4.1

* Thu Oct 30 2014 Lukas Zapletal <lzap+git@redhat.com> 1.4.0-2
- Update to foreman_discovery 1.4.0-2

* Thu Oct 30 2014 Lukas Zapletal <lzap+git@redhat.com> 1.4.0-1
- Updated foreman_discovery to 1.4.0 (lzap+git@redhat.com)

* Wed Oct 01 2014 Lukas Zapletal <lzap+git@redhat.com> 1.4.0-0.1.rc4
- Update rubygem-foreman_discovery to 1.4.0.rc4 (lzap+git@redhat.com)

* Wed Oct 01 2014 Lukas Zapletal <lzap+rpm@redhat.com> - 1.4.0-0.1.rc4
- Update foreman_discovery to 1.4.0.rc4

* Tue Sep 23 2014 Dominic Cleal <dcleal@redhat.com> 1.4.0-0.1.rc3
- Update foreman_discovery to 1.4.0.rc3 (dcleal@redhat.com)

* Mon Sep 22 2014 Dominic Cleal <dcleal@redhat.com> 1.4.0-0.1.rc2
- Update foreman_discovery to 1.4.0.rc2 (dcleal@redhat.com)

* Thu Aug 28 2014 Dominic Cleal <dcleal@redhat.com> 1.4.0-0.1.rc1
- Update foreman_discovery to 1.4.0.rc1 (dcleal@redhat.com)

* Fri Jun 06 2014 Lukas Zapletal <lzap+git@redhat.com> 1.3.0-1
- Updated foreman_discovery to 1.3.0 final version (lzap+git@redhat.com)

* Wed May 21 2014 Dominic Cleal <dcleal@redhat.com> 1.3.0-0.1.rc3
- Update foreman_discovery to 1.3.0.rc3 (dcleal@redhat.com)

* Fri Apr 18 2014 Lukas Zapletal <lzap+git@redhat.com> 1.3.0-0.1.rc2
- foreman_discovery-1.3.0.rc2 bump (lzap+git@redhat.com)
- Set minimum Foreman version of 1.5 (dcleal@redhat.com)

* Wed Apr 09 2014 Marek Hulan <mhulan@redhat.com> 1.3.0-0.1.rc1
- Update foreman discovery (mhulan@redhat.com)

* Wed Apr 02 2014 Dominic Cleal <dcleal@redhat.com> 1.2.0-1
- Update to 1.2.0 (dcleal@redhat.com)

* Fri Jan 24 2014 Lukas Zapletal <lzap+git@redhat.com> 1.2.0-0.1.rc2
- Bump foreman_discovery to 1.2.0.rc2 (lzap+git@redhat.com)
- Bump foreman_discovery to 1.2.0.rc1 (lzap+git@redhat.com)

* Sat Oct 19 2013 Dominic Cleal <dcleal@redhat.com> 1.1.1-1
- Update to 1.1.1 (dcleal@redhat.com)

* Fri Oct 18 2013 Dominic Cleal <dcleal@redhat.com> 1.1.0-1
- Update to 1.1.0 (dcleal@redhat.com)

* Thu Aug 22 2013 Dominic Cleal <dcleal@redhat.com> 1.0.2-7
- Create ~foreman/discovery_dir for image building (dcleal@redhat.com)
- Add patch for #2949, don't use bundler to find build_iso.sh
  (dcleal@redhat.com)
- Add dependencies and sudoers file for image building (dcleal@redhat.com)
- Remove SCL prefix from foreman-plugin-* provide (dcleal@redhat.com)

* Tue Aug 13 2013 Lukas Zapletal <lzap+git@redhat.com> 1.0.2-6
- adding SCL prefix to the provides statement (lzap+git@redhat.com)
- fixing dependency name (lzap+git@redhat.com)

* Tue Aug 13 2013 Lukas Zapletal <lzap+git@redhat.com> 1.0.2-5
- adding provides statement (lzap+git@redhat.com)

* Mon Aug 12 2013 Lukas Zapletal <lzap+git@redhat.com> 1.0.2-4
- adding missing source file (lzap+git@redhat.com)

* Mon Aug 12 2013 Lukas Zapletal <lzap+git@redhat.com> 1.0.2-3
- removing alpha tags (lzap+git@redhat.com)

* Thu Aug 01 2013 Lukas Zapletal <lzap+rpm[@]redhat.com> - 1.0.2-1
- bump to 1.0.2 release

* Wed Jun 26 2013 Dominic Cleal <dcleal@redhat.com> 1.0.0-0.1.rc4
- initial package build
